@@ -194,7 +194,7 @@ fn get_meson_version(context: &Context, config: &PackageConfig) -> Option<String
         .split_ascii_whitespace()
         .collect::<String>();
 
-    let re = Regex::new(r#"project\([^())]*,version:'(?P<version>[^']+)'[^())]*\)"#).unwrap();
+    let re = Regex::new(r"project\([^())]*,version:'(?P<version>[^']+)'[^())]*\)").unwrap();
     let caps = re.captures(&file_contents)?;
 
     format_version(&caps["version"], config.version_format)
@@ -310,6 +310,13 @@ fn get_dart_pub_version(context: &Context, config: &PackageConfig) -> Option<Str
     format_version(raw_version, config.version_format)
 }
 
+fn get_rlang_version(context: &Context, config: &PackageConfig) -> Option<String> {
+    let file_contents = context.read_file_from_pwd("DESCRIPTION")?;
+    let re = Regex::new(r"(?m)^Version:\s*(?P<version>.*$)").unwrap();
+    let caps = re.captures(&file_contents)?;
+    format_version(&caps["version"], config.version_format)
+}
+
 fn get_version(context: &Context, config: &PackageConfig) -> Option<String> {
     let package_version_fn: Vec<fn(&Context, &PackageConfig) -> Option<String>> = vec![
         get_cargo_version,
@@ -330,6 +337,7 @@ fn get_version(context: &Context, config: &PackageConfig) -> Option<String> {
         get_sbt_version,
         get_daml_project_version,
         get_dart_pub_version,
+        get_rlang_version,
     ];
 
     package_version_fn.iter().find_map(|f| f(context, config))
@@ -487,12 +495,12 @@ mod tests {
     fn test_extract_nimble_package_version() -> io::Result<()> {
         let config_name = "test_project.nimble";
 
-        let config_content = r##"
+        let config_content = r#"
 version = "0.1.0"
 author = "Mr. nimble"
 description = "A new awesome nimble package"
 license = "MIT"
-"##;
+"#;
 
         let project_dir = create_project_dir()?;
         fill_config(&project_dir, config_name, Some(config_content))?;
@@ -505,7 +513,7 @@ license = "MIT"
             .cmd(
                 "nimble dump --json",
                 Some(CommandOutput {
-                    stdout: r##"
+                    stdout: r#"
 {
   "name": "test_project.nimble",
   "version": "0.1.0",
@@ -524,7 +532,7 @@ license = "MIT"
   "srcDir": "",
   "backend": "c"
 }
-"##
+"#
                     .to_owned(),
                     stderr: String::new(),
                 }),
@@ -547,12 +555,12 @@ license = "MIT"
     ) -> io::Result<()> {
         let config_name = "test_project.nimble";
 
-        let config_content = r##"
+        let config_content = r#"
 version = "0.1.0"
 author = "Mr. nimble"
 description = "A new awesome nimble package"
 license = "MIT"
-"##;
+"#;
 
         let project_dir = create_project_dir()?;
         fill_config(&project_dir, config_name, Some(config_content))?;
@@ -1402,6 +1410,19 @@ environment:
         project_dir.close()
     }
 
+    #[test]
+    fn test_extract_rlang_version() -> io::Result<()> {
+        let config_name = "DESCRIPTION";
+        let config_content = "
+Package: starship
+Version: 1.0.0
+Title: Starship
+";
+        let project_dir = create_project_dir()?;
+        fill_config(&project_dir, config_name, Some(config_content))?;
+        expect_output(&project_dir, Some("v1.0.0"), None);
+        project_dir.close()
+    }
     fn create_project_dir() -> io::Result<TempDir> {
         tempfile::tempdir()
     }
